/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (c) 2023 Meta Platforms, Inc. and affiliates.
 */

#pragma once

#include <bpfilter/flavor.h>

extern const struct bf_flavor_ops bf_flavor_ops_tc;
